from .nada import *

def nothing():
    return "I told you, it does nothing."
